@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_usb.c 3936 2007-10-18 20:02:25Z roms $ */
+/* $Id: link_usb.c 4238 2009-05-03 13:03:06Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (c) 1999-2006 Romain Lievin
@@ -688,7 +688,7 @@ int slv_bulk_read2(usb_dev_handle *dev, int ep, char *bytes, int size,
 
   if (!io_pending)
     {
-      ret = usb_bulk_setup_async(dev, &context, ep);
+      ret = usb_bulk_setup_async(dev, &context, (unsigned char)ep);
 
       if(ret < 0)
         {
